pub struct GetPlaylistItems {
pub id: String,
pub market: Option<Market>,
}Expand description
Get full details of the items of a playlist owned by a Spotify user.
Fields
id: StringThe Spotify ID of the playlist.
market: Option<Market>An ISO 3166-1 alpha-2 country code. If a country code is specified, only content that is available in that market will be returned. If a valid user access token is specified in the request header, the country associated with the user account will take priority over this parameter.
Notes
If neither market or user country are provided, the content is considered unavailable for the client. Users can view the country that is associated with their account in the account settings.