Struct GetUserSavedTracks

pub struct GetUserSavedTracks {
    pub market: Option<Market>,
}
Get a list of the tracks saved in the current Spotify user’s library.

This API endpoint is in beta and could change without warning. Please share any feedback that you have, or issues that you discover, in the Spotify developer community forum.

Fields

market: Option<Market>

An ISO 3166-1 alpha-2 country code. If a country code is specified, only content that is available in that market will be returned. If a valid user access token is specified in the request header, the country associated with the user account will take priority over this parameter.

Notes

If neither market or user country are provided, the content is considered unavailable for the client. Users can view the country that is associated with their account in the account settings.