Spotify Web API data model.
This module contains all data types returned by the Spotify Web API, organized by resource type.
Feature Flags
Some fields are conditionally compiled based on feature flags:
markets(default): Includesavailable_marketsfields on tracks, albums, etc.page_items(default): Includesitemsfields on paginated responses.
Common Types
Page- Paginated response wrapperImage- Image metadataExternalUrls- External URL links (Spotify URLs)Followers- Follower information
Re-exports
pub use albums::*;pub use artists::*;pub use audiobooks::*;pub use categories::*;pub use chapters::*;pub use episodes::*;pub use genres::*;pub use id::*;pub use markets::*;pub use misc::*;pub use player::*;pub use playlists::*;pub use search::*;pub use shows::*;pub use token::*;pub use tracks::*;pub use users::*;