Struct Audiobook

pub struct Audiobook {
Show 20 fields pub authors: Vec<Author>, pub available_markets: Vec<Market>, pub copyrights: Vec<Copyright>, pub description: String, pub html_description: String, pub edition: String, pub explicit: bool, pub external_urls: ExternalUrls, pub href: String, pub id: String, pub images: Vec<Image>, pub languages: Vec<String>, pub media_type: String, pub name: String, pub narrators: Vec<Narrator>, pub publisher: String, pub type_: ItemType, pub uri: String, pub total_chapters: usize, pub chapters: Page<SimplifiedChapter>,
}

Fields

authors: Vec<Author>

The author(s) for the audiobook.

available_markets: Vec<Market>

A list of the countries in which the audiobook can be played, identified by their ISO 3166-1 alpha-2 code.

copyrights: Vec<Copyright>

The copyright statements of the audiobook.

description: String

A description of the audiobook. HTML tags are stripped away from this field, use html_description field in case HTML tags are needed.

html_description: String

A description of the audiobook. This field may contain HTML tags.

edition: String

The edition of the audiobook.

explicit: bool

Whether or not the audiobook has explicit content (true = yes it does; false = no it does not OR unknown).

external_urls: ExternalUrls

External URLs for this audiobook.

href: String

A link to the Web API endpoint providing full details of the audiobook.

id: String

The Spotify ID for the audiobook.

images: Vec<Image>

The cover art for the audiobook in various sizes, widest first.

languages: Vec<String>

A list of the languages used in the audiobook, identified by their ISO 639 code.

media_type: String

The media type of the audiobook.

name: String

The name of the audiobook.

narrators: Vec<Narrator>

The narrator(s) for the audiobook.

publisher: String

The publisher of the audiobook.

type_: ItemType

The object type.

Allowed values: “audiobook”

uri: String

The Spotify URI for the audiobook.

total_chapters: usize

The number of chapters in this audiobook.

chapters: Page<SimplifiedChapter>

A list of simplified chapters in this audiobook.