Struct AlbumId

pub struct AlbumId(/* private fields */);

Implementations

Source

impl AlbumId

pub fn from_id<S>(id: S) -> Result<Self, IdError>
where S: Into<String>,

pub fn from_uri<S>(uri: S) -> Result<Self, IdError>
where S: Into<String>,

pub fn id(&self) -> &str

The base-62 identifier found at the end of the Spotify URI (see above) for an artist, track, album, playlist, etc. Unlike a Spotify URI, a Spotify ID does not clearly identify the type of resource; that information is provided elsewhere in the call.

pub fn _type(&self) -> IdType

The type of the resource.

pub fn uri(&self) -> String

The resource identifier of, for example, an artist, album or track.