Module misc

Module misc 

Structs

Copyright
Copyright information for an album or show.
Cursors
Cursors for cursor-based pagination.
ExternalIds
External IDs for a track (ISRC, EAN, UPC).
ExternalUrls
External URLs for a Spotify object.
Followers
Follower information for a user, artist, or playlist.
Icon
An icon image.
Image
An image from Spotify (album art, user avatar, etc.).
Page
A paginated response containing a list of items.
Restrictions
Content restrictions applied to an item.
ResumePoint
Resume point for a podcast episode.
VideoThumbnail
A video thumbnail image.

Enums

CopyrightType
The type of copyright.
FollowType
The type of entity to follow (artist or user).
FollowedArtistsType
The type filter for fetching followed artists.
IncludeExternalType
Type of external content to include in search results.
ItemType
The type of a Spotify item.
ReleaseDatePrecision
The precision of a release date.
TimeRange
Time range for fetching user’s top items.
TopItem
A user’s top item, which can be either an artist or a track.
TopItemType
The type of top items to fetch (artists or tracks).
TrackItem
A currently playing item, which can be either a track or an episode.

Type Aliases

TopItems
A paginated list of the user’s top items.