Module player

Module player 

Structs

Actions
Available playback actions in the current context.
Context
The playback context (album, playlist, artist, etc.).
CurrentlyPlaying
Information about the currently playing track or episode.
Device
A playback device (speaker, phone, computer, etc.).
Devices
A list of available playback devices.
PlayHistory
A track in the user’s play history.
PlaybackState
The current playback state including device, track, and progress.
Queue
The user’s playback queue.
RecentlyPlayedTracks
A list of recently played tracks.

Enums

CurrentlyPlayingType
The type of the currently playing item.
Offset
An offset for starting playback at a specific position or URI.
PlaylistItem
An item that can be added to a playlist (track or episode).
QueryRange
A time range for querying recently played tracks.
RepeatState
The repeat mode state for playback.