pub type AsyncSpotifyPKCE = AsyncSpotify<AuthCodePKCE>;Expand description
Type alias for an async Spotify client using Authorization Code with PKCE flow.
Aliased Type
pub struct AsyncSpotifyPKCE { /* private fields */ }pub type AsyncSpotifyPKCE = AsyncSpotify<AuthCodePKCE>;Type alias for an async Spotify client using Authorization Code with PKCE flow.
pub struct AsyncSpotifyPKCE { /* private fields */ }