pub struct Audiobook {Show 20 fields
pub authors: Vec<Author>,
pub available_markets: Vec<Market>,
pub copyrights: Vec<Copyright>,
pub description: String,
pub html_description: String,
pub edition: String,
pub explicit: bool,
pub external_urls: ExternalUrls,
pub href: String,
pub id: String,
pub images: Vec<Image>,
pub languages: Vec<String>,
pub media_type: String,
pub name: String,
pub narrators: Vec<Narrator>,
pub publisher: String,
pub type_: ItemType,
pub uri: String,
pub total_chapters: usize,
pub chapters: Page<SimplifiedChapter>,
}Fields
The author(s) for the audiobook.
available_markets: Vec<Market>A list of the countries in which the audiobook can be played, identified by their ISO 3166-1 alpha-2 code.
copyrights: Vec<Copyright>The copyright statements of the audiobook.
description: StringA description of the audiobook. HTML tags are stripped away from this field,
use html_description field in case HTML tags are needed.
html_description: StringA description of the audiobook. This field may contain HTML tags.
edition: StringThe edition of the audiobook.
explicit: boolWhether or not the audiobook has explicit content (true = yes it does; false = no it does not OR unknown).
external_urls: ExternalUrlsExternal URLs for this audiobook.
href: StringA link to the Web API endpoint providing full details of the audiobook.
id: StringThe Spotify ID for the audiobook.
images: Vec<Image>The cover art for the audiobook in various sizes, widest first.
languages: Vec<String>A list of the languages used in the audiobook, identified by their ISO 639 code.
media_type: StringThe media type of the audiobook.
name: StringThe name of the audiobook.
narrators: Vec<Narrator>The narrator(s) for the audiobook.
publisher: StringThe publisher of the audiobook.
type_: ItemTypeThe object type.
Allowed values: “audiobook”
uri: StringThe Spotify URI for the audiobook.
total_chapters: usizeThe number of chapters in this audiobook.
chapters: Page<SimplifiedChapter>A list of simplified chapters in this audiobook.