Structs
- Copyright
- Copyright information for an album or show.
- Cursors
- Cursors for cursor-based pagination.
- External
Ids - External IDs for a track (ISRC, EAN, UPC).
- External
Urls - External URLs for a Spotify object.
- Followers
- Follower information for a user, artist, or playlist.
- Icon
- An icon image.
- Image
- An image from Spotify (album art, user avatar, etc.).
- Page
- A paginated response containing a list of items.
- Restrictions
- Content restrictions applied to an item.
- Resume
Point - Resume point for a podcast episode.
- Video
Thumbnail - A video thumbnail image.
Enums
- Copyright
Type - The type of copyright.
- Follow
Type - The type of entity to follow (artist or user).
- Followed
Artists Type - The type filter for fetching followed artists.
- Include
External Type - Type of external content to include in search results.
- Item
Type - The type of a Spotify item.
- Release
Date Precision - The precision of a release date.
- Time
Range - Time range for fetching user’s top items.
- TopItem
- A user’s top item, which can be either an artist or a track.
- TopItem
Type - The type of top items to fetch (artists or tracks).
- Track
Item - A currently playing item, which can be either a track or an episode.
Type Aliases
- TopItems
- A paginated list of the user’s top items.