pub struct Playlist {Show 15 fields
pub collaborative: bool,
pub description: Option<String>,
pub external_urls: ExternalUrls,
pub followers: Followers,
pub href: String,
pub id: String,
pub images: Option<Vec<Image>>,
pub name: String,
pub owner: UserReference,
pub primary_color: Option<String>,
pub public: Option<bool>,
pub snapshot_id: String,
pub tracks: Page<PlaylistTrack>,
pub type_: ItemType,
pub uri: String,
}Fields
collaborative: booltrue if the owner allows other users to modify the playlist.
description: Option<String>The playlist description. Only returned for modified, verified playlists, otherwise None.
external_urls: ExternalUrlsKnown external URLs for this playlist.
followers: FollowersInformation about the followers of the playlist.
href: StringA link to the Web API endpoint providing full details of the playlist.
id: StringThe Spotify ID for the playlist.
images: Option<Vec<Image>>Images for the playlist. The array may be empty or contain up to three images.
name: StringThe name of the playlist.
owner: UserReferenceThe user who owns the playlist
primary_color: Option<String>Gradient color of the playlist’s cover image. Will always be None as this is only used internally by Spotify.
public: Option<bool>The playlist’s public/private status: true the playlist is public, false the playlist is private, null the playlist status is not relevant.
snapshot_id: StringThe version identifier for the current playlist. Can be supplied in other requests to target a specific playlist version
tracks: Page<PlaylistTrack>The tracks of the playlist.
type_: ItemTypeThe object type: “playlist”
uri: StringThe Spotify URI for the playlist.